macro_rules! debug_assert_none {
($($arg:tt)*) => { ... };
}Expand description
Asserts that the expression is None on debug builds.
This macro behaves the same as assert_none! on debug builds. On release builds it is a
no-op.
macro_rules! debug_assert_none {
($($arg:tt)*) => { ... };
}Asserts that the expression is None on debug builds.
This macro behaves the same as assert_none! on debug builds. On release builds it is a
no-op.